import os
import sys
from logging import warn

from dotenv import load_dotenv
from telethon.sessions import StringSession
from telethon.sync import TelegramClient

load_dotenv()


def login(API_ID, API_HASH):
    print(
        "\nYou are now going to login, and the session string will be sent securely to your telegram account. \nYou need to copy that for future use.\n\n"
    )
    print(
        "If you now login with your phone no, the session string will be saved in you Telgram's Saved Messages.\n"
    )
    print(
        "If you login with a bot account, the bot will send the session string to your username."
    )

    input("\nPress [ENTER] to proceed\n")

    with TelegramClient(StringSession(), API_ID, API_HASH).start() as client:
        session_string = client.session.save()
        message = f"Your session string is: \n\n`{session_string}`\n\nKeep this secret!"

        me = client.get_me()
        print(f"\n\n{me.username}\n\n")
        if me.bot:
            print(
                f"Bot account detected! Open your telegram app, and send /start to {me.username}"
            )
            input("Press [ENTER] after you have send /start\n\n")
            uname = input(
                "What is your telegram username ? \n(the username of the user account from which you sent /start to the bot just now ) \n: "
            )
            confirm = input("Please type your username again: ")
            if uname == confirm:
                input(
                    f"Are you sure your username is {uname} ? Press ENTER to continue. The session string will be sent to you."
                )
                client.send_message(uname, message)
                print(f"The session string has been succesfully sent to {uname}")
            else:
                print(
                    "The username you typed second time did not match with the first time! Quitting.\n\n You can start again!"
                )
                sys.exit(1)
        else:
            client.send_message("me", message)
            print("Open your saved messages in telegram to see your session string!")

        warning = """
        \n\n
        - Keep this string safe! Dont leak it.

        - Anyone with this string can use it to login into your account and do anything they want to to do.

        - For more information about Telethon Session Strings
        \thttps://docs.telethon.dev/en/latest/concepts/sessions.html#string-sessions

        - You can deactivate this session by going to your
        \tTelegram App -> Settings -> Devices -> Active sessions

        """

        print(warning)

    return session_string



from typing import Optional

import typer
from dotenv import load_dotenv

from tg_login import __version__
from tg_login.login import login

app = typer.Typer(add_completion=False)

load_dotenv()


def version_callback(value: bool):
    if value:
        print(__version__)
        raise typer.Exit()


@app.command()
def main(
    API_ID: int = typer.Option(
        ...,
        "--API_ID",
        help="API ID obtained from my.telegram.org",
        envvar="API_ID",
        prompt="Paste your API ID (input hidden)",
        hide_input=True,
    ),
    API_HASH: str = typer.Option(
        ...,
        "--API_HASH",
        help="API HASH obtained from my.telegram.org",
        envvar="API_HASH",
        prompt="Paste your API HASH (input hidden)",
        hide_input=True,
    ),
    version: Optional[bool] = typer.Option(
        None,
        "--version",
        "-v",
        callback=version_callback,
        help="Show version and exit.",
    ),
):
    """ A command line tool to login into Telegram with user or bot accounts. """

    login(API_ID, API_HASH)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tg_login']

package_data = \
{'': ['*']}

install_requires = \
['Telethon>=1.21.1,<2.0.0',
 'python-dotenv>=0.17.0,<0.18.0',
 'typer>=0.3.2,<0.4.0']

entry_points = \
{'console_scripts': ['tg-login = tg_login.cli:app']}

setup_kwargs = {
    'name': 'tg-login',
    'version': '0.0.2',
    'description': 'A command line tool to login into Telegram with user or bot accounts.',
    'long_description': "# tg-login\n\nA command line tool to login into Telegram with user or bot accounts.\n\n<!-- ## Why\n\nWhy the need of a seperate tool like `tg-login` ? -->\n\n## Installation\n\n```shell\npip install tg-login\n```\n\n## Usage\n\n```shell\nUsage: tg-login [OPTIONS]\n\n  A command line tool to login into Telegram with user or bot accounts.\n\nOptions:\n  --API_ID INTEGER  API ID obtained from my.telegram.org  [env var: API_ID;\n                    required]\n\n  --API_HASH TEXT   API HASH obtained from my.telegram.org  [env var:\n                    API_HASH; required]\n\n  -v, --version     Show version and exit.\n  --help            Show this message and exit.\n```\n\n<!-- The `API_ID` ,`API_HASH`, `BOT_TOKEN`, `PHONE_NO`, can be passed as CLI options, or can be set as environment variables.\n\nProvide either `BOT_TOKEN` or `PHONE_NO`. If both are found, `tg-login` will use the bot account.\n\n`tg-login` by default generates the session string and saves it in your Telegram's Saved Messages.\n\nIf the `--session=file` option is provided, it will generated a session file. -->\n",
    'author': 'aahnik',
    'author_email': 'daw@aahnik.dev',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/aahnik/tg-login',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
